==> zio-aws-transcribestreaming_2.13-5.17.127.2-sources.jar: zio/aws/transcribestreaming/model/package.scala <==
package zio.aws.transcribestreaming
import zio.prelude.Subtype
import zio.Chunk
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AudioChunk extends Subtype[Chunk[Byte]]
    type AudioChunk =
      zio.aws.transcribestreaming.model.primitives.AudioChunk.Type
    object Confidence extends Subtype[Double]
    type Confidence =
      zio.aws.transcribestreaming.model.primitives.Confidence.Type
    object LanguageOptions extends Subtype[String]
    type LanguageOptions =
      zio.aws.transcribestreaming.model.primitives.LanguageOptions.Type
    object MediaSampleRateHertz extends Subtype[Int]
    type MediaSampleRateHertz =
      zio.aws.transcribestreaming.model.primitives.MediaSampleRateHertz.Type
    object ModelName extends Subtype[String]
    type ModelName = zio.aws.transcribestreaming.model.primitives.ModelName.Type
    object NumberOfChannels extends Subtype[Int]
    type NumberOfChannels =
      zio.aws.transcribestreaming.model.primitives.NumberOfChannels.Type
    object PiiEntityTypes extends Subtype[String]
    type PiiEntityTypes =
      zio.aws.transcribestreaming.model.primitives.PiiEntityTypes.Type
    object SessionId extends Subtype[String]
    type SessionId = zio.aws.transcribestreaming.model.primitives.SessionId.Type
    object Stable extends Subtype[Boolean]
    type Stable = zio.aws.transcribestreaming.model.primitives.Stable.Type
    object VocabularyFilterName extends Subtype[String]
    type VocabularyFilterName =
      zio.aws.transcribestreaming.model.primitives.VocabularyFilterName.Type
    object VocabularyName extends Subtype[String]
    type VocabularyName =
      zio.aws.transcribestreaming.model.primitives.VocabularyName.Type
  }
  type AlternativeList = List[zio.aws.transcribestreaming.model.Alternative]
  type EntityList = List[zio.aws.transcribestreaming.model.Entity]
  type ItemList = List[zio.aws.transcribestreaming.model.Item]
  type LanguageIdentification =
    List[zio.aws.transcribestreaming.model.LanguageWithScore]
  type MedicalAlternativeList =
    List[zio.aws.transcribestreaming.model.MedicalAlternative]
  type MedicalEntityList = List[zio.aws.transcribestreaming.model.MedicalEntity]
  type MedicalItemList = List[zio.aws.transcribestreaming.model.MedicalItem]
  type MedicalResultList = List[zio.aws.transcribestreaming.model.MedicalResult]
  type ResultList = List[zio.aws.transcribestreaming.model.Result]
}

==> zio-aws-transcribestreaming_2.13-7.21.15.8-sources.jar: zio/aws/transcribestreaming/model/package.scala <==
package zio.aws.transcribestreaming
import zio.prelude.Subtype
import zio.Chunk
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AudioChunk extends Subtype[Chunk[Byte]]
    type AudioChunk =
      zio.aws.transcribestreaming.model.primitives.AudioChunk.Type
    object ChannelId extends Subtype[Int]
    type ChannelId = zio.aws.transcribestreaming.model.primitives.ChannelId.Type
    object Confidence extends Subtype[Double]
    type Confidence =
      zio.aws.transcribestreaming.model.primitives.Confidence.Type
    type Integer = Int
    object LanguageOptions extends Subtype[String]
    type LanguageOptions =
      zio.aws.transcribestreaming.model.primitives.LanguageOptions.Type
    object MediaSampleRateHertz extends Subtype[Int]
    type MediaSampleRateHertz =
      zio.aws.transcribestreaming.model.primitives.MediaSampleRateHertz.Type
    object ModelName extends Subtype[String]
    type ModelName = zio.aws.transcribestreaming.model.primitives.ModelName.Type
    object NumberOfChannels extends Subtype[Int]
    type NumberOfChannels =
      zio.aws.transcribestreaming.model.primitives.NumberOfChannels.Type
    object PiiEntityTypes extends Subtype[String]
    type PiiEntityTypes =
      zio.aws.transcribestreaming.model.primitives.PiiEntityTypes.Type
    object SessionId extends Subtype[String]
    type SessionId = zio.aws.transcribestreaming.model.primitives.SessionId.Type
    object Stable extends Subtype[Boolean]
    type Stable = zio.aws.transcribestreaming.model.primitives.Stable.Type
    object VocabularyFilterName extends Subtype[String]
    type VocabularyFilterName =
      zio.aws.transcribestreaming.model.primitives.VocabularyFilterName.Type
    object VocabularyFilterNames extends Subtype[String]
    type VocabularyFilterNames =
      zio.aws.transcribestreaming.model.primitives.VocabularyFilterNames.Type
    object VocabularyName extends Subtype[String]
    type VocabularyName =
      zio.aws.transcribestreaming.model.primitives.VocabularyName.Type
    object VocabularyNames extends Subtype[String]
    type VocabularyNames =
      zio.aws.transcribestreaming.model.primitives.VocabularyNames.Type
  }
  type AlternativeList = List[zio.aws.transcribestreaming.model.Alternative]
  type CallAnalyticsEntityList =
    List[zio.aws.transcribestreaming.model.CallAnalyticsEntity]
  type CallAnalyticsItemList =
    List[zio.aws.transcribestreaming.model.CallAnalyticsItem]
  type ChannelDefinitions =
    List[zio.aws.transcribestreaming.model.ChannelDefinition]
  type EntityList = List[zio.aws.transcribestreaming.model.Entity]
  type IssuesDetected = List[zio.aws.transcribestreaming.model.IssueDetected]
  type ItemList = List[zio.aws.transcribestreaming.model.Item]
  type LanguageIdentification =
    List[zio.aws.transcribestreaming.model.LanguageWithScore]
  type MedicalAlternativeList =
    List[zio.aws.transcribestreaming.model.MedicalAlternative]
  type MedicalEntityList = List[zio.aws.transcribestreaming.model.MedicalEntity]
  type MedicalItemList = List[zio.aws.transcribestreaming.model.MedicalItem]
  type MedicalResultList = List[zio.aws.transcribestreaming.model.MedicalResult]
  type ResultList = List[zio.aws.transcribestreaming.model.Result]
}
